# https://github.com/numpy/numpy/releases/download/v1.14.2/numpy-1.14.2.tar.gz
%global _disable_ld_no_undefined 1
%define enable_atlas 0
%define module numpy
%define name python-%{module}
%define enable_tests 0
%define enable_doc 0

Name:           python-%{module}
Version:        1.14.2
Release:        %mkrel 2
Summary:        A fast multidimensional array facility for Python

License:        BSD and Python
Group:          Development/Python
Url:            http://www.numpy.org
Source0:        %{module}-%{version}.tar.xz

%if %enable_atlas
BuildRequires:	libatlas-devel
%else
BuildRequires:	%{_lib}blas-devel
BuildRequires:  %{_lib}cblas-devel
%endif
BuildRequires:	gcc-gfortran >= 4.0
BuildRequires:  %{_lib}lapack-devel
BuildRequires:  libquadmath-devel
%if %enable_doc
BuildRequires:	python-sphinx >= 1.0
BuildRequires:  python-sphinx_rtd_theme
BuildRequires:	python-matplotlib
BuildRequires:	python3-sphinx >= 1.0
BuildRequires:  python3-sphinx_rtd_theme
BuildRequires:	python3-matplotlib
%endif
%if %enable_tests
BuildRequires:	python-nose
BuildRequires:	python3-nose
%endif
BuildRequires:  python-cython
BuildRequires:	python-devel
BuildRequires:	python-setuptools
BuildRequires:  python3-cython
BuildRequires:	python3-devel
BuildRequires:	python3-setuptools
%rename         python-numeric

%description
Numpy is a general-purpose array-processing package designed to
efficiently manipulate large multi-dimensional arrays of arbitrary
records without sacrificing too much speed for small multi-dimensional
arrays. Numpy is built on the Numeric code base and adds features
introduced by numarray as well as an extended C-API and the ability to
create arrays of arbitrary type.

Numpy also provides facilities for basic linear algebra routines,
basic Fourier transforms, and random number generation.

%package devel
Summary:        Numpy headers
Group:		      Development/Python
Requires:	      %{name} = %{version}-%{release}
Requires:       %{name}-f2py = %{version}-%{release}
Requires:       python-devel
%rename         python-numeric-devel

%description devel
This package contains header files need to develop modules
in C and Fortran that can interact with Numpy

%package f2py
Summary:        f2py for numpy
Group:          Development/Python
Requires:       %{name} = %{version}-%{release}
%rename         f2py

%description f2py
This package includes a version of f2py that works properly with NumPy.

%package -n python3-%{module}
Summary:        A fast multidimensional array facility for Python3
Group:		      Development/Python
License:        BSD

%description -n python3-%{module}
Numpy is a general-purpose array-processing package designed to
efficiently manipulate large multi-dimensional arrays of arbitrary
records without sacrificing too much speed for small multi-dimensional
arrays. Numpy is built on the Numeric code base and adds features
introduced by numarray as well as an extended C-API and the ability to
create arrays of arbitrary type.

Numpy also provides facilities for basic linear algebra routines,
basic Fourier transforms, and random number generation.

%package -n python3-%{module}-devel
Summary:        Numpy headers
Group:		      Development/Python
Requires:       python3-%{module} = %{version}-%{release}
Requires:       python3-%{module}-f2py = %{version}-%{release}
Requires:       python3-devel
%rename         python3-numeric-devel

%description -n python3-numpy-devel
This package contains header files need to develop modules
in C and Fortran that can interact with Numpy

%package -n python3-%{module}-f2py
Summary:        f2py for numpy
Group:          Development/Python
Requires:       python3-numpy = %{version}-%{release}
%rename         python3-f2py

%description -n python3-numpy-f2py
This package includes a version of f2py that works properly with NumPy.

%prep
%setup -qn %{module}-%{version}

# workaround for rhbz#849713
# http://mail.scipy.org/pipermail/numpy-discussion/2012-July/063530.html
rm numpy/distutils/command/__init__.py && touch numpy/distutils/command/__init__.py

cat >> site.cfg <<EOF
[atlas]
library_dirs = cblas
atlas_libs = cblas
EOF

cp -a . %{py3dir}

%build
pushd %{py3dir}
env ATLAS=None FFTW=%{_libdir} BLAS=%{_libdir} \
    CFLAGS="%{optflags} -fPIC -O3" LDFLAGS="%{ldflags} -shared" \
    %{__python3} setup.py config_fc --fcompiler=gnu95 build
popd

env ATLAS=None FFTW=%{_libdir} BLAS=%{_libdir} \
    CFLAGS="%{optflags} -fPIC -O3" LDFLAGS="%{ldflags} -shared" \
    %{__python2} setup.py config_fc --fcompiler=gnu95 build

%if %enable_doc
pushd doc
export PYTHONPATH=`dir -d ../build/lib.linux*`
%make html
popd
%endif

%install
pushd %{py3dir}
env ATLAS=None FFTW=%{_libdir} BLAS=%{_libdir} \
    CFLAGS="%{optflags} -fPIC -O3" LDFLAGS="%{ldflags} -shared" \
    %{__python3} setup.py install --root %{buildroot}
popd

env ATLAS=None FFTW=%{_libdir} BLAS=%{_libdir} \
    CFLAGS="%{optflags} -fPIC -O3" LDFLAGS="%{ldflags} -shared" \
    %{__python2} setup.py install --root %{buildroot}
pushd %{buildroot}%{_bindir} &> /dev/null
ln -s f2py2 f2py.numpy
popd &> /dev/null

# symlink for includes
mkdir -p %{buildroot}%{py2_incdir}
ln -s %{python2_sitearch}/%{module}/core/include/%{module} %{buildroot}%{py2_incdir}/%{module}

mkdir -p %{buildroot}%{py3_incdir}
ln -s %{python2_sitearch}/%{module}/core/include/%{module} %{buildroot}%{py3_incdir}/%{module}

# Remove doc files that should be in %doc:
%__rm -f %{buildroot}%{py_platsitedir}/%{module}/LICENSE.txt

%check
%if %enable_tests
pushd doc &> /dev/null
PYTHONPATH="%{buildroot}%{python2_sitearch}" %{__python2} -c "import pkg_resources, numpy ; numpy.test(verbose=2)" \
popd &> /dev/null

pushd doc &> /dev/null
PYTHONPATH="%{buildroot}%{python3_sitearch}" %{__python3} -c "import pkg_resources, numpy ; numpy.test(verbose=2)" \
popd &> /dev/null
%endif

%files
%doc THANKS.txt site.cfg.example LICENSE.txt
%if %enable_doc
%doc doc/build/html
%endif
%{python2_sitearch}/*
%exclude %{python2_sitearch}/%{module}/core/include/
%exclude %{python2_sitearch}/%{module}/core/lib
%exclude %{python2_sitearch}/%{module}/f2py
%exclude %{python2_sitearch}/%{module}/random/randomkit.h

%files devel
%{py2_incdir}/%{module}
%{python2_sitearch}/%{module}/core/include/
%{python2_sitearch}/%{module}/core/lib
%{python2_sitearch}/%{module}/random/randomkit.h

%files f2py
%{_bindir}/f2py2
%{_bindir}/f2py.numpy
%{python2_sitearch}/%{module}/f2py

%files -n python3-%{module}
%doc THANKS.txt site.cfg.example LICENSE.txt
%{python3_sitearch}/*
%exclude %{python3_sitearch}/%{module}/core/include/
%exclude %{python3_sitearch}/%{module}/core/lib
%exclude %{python3_sitearch}/%{module}/f2py
%exclude %{python3_sitearch}/%{module}/random/randomkit.h

%files -n python3-%{module}-f2py
%{_bindir}/f2py3
%{python3_sitearch}/%{module}/f2py

%files -n python3-%{module}-devel
%{py3_incdir}/%{module}
%{python3_sitearch}/%{module}/core/include/
%{python3_sitearch}/%{module}/core/lib
%{python3_sitearch}/%{module}/random/randomkit.h

%changelog
* Sun Jul 01 2018 adrianomorselli <adrianomorselli> 1.14.2-2uplos2018
- update
- fix incorrect dependencies
